@@ -38,6 +38,9 @@
 #ifdef WITH_SYSTEMD
 #include <systemd/sd-login.h>
 #endif
+#ifdef WITH_ELOGIND
+#include <elogind/sd-login.h>
+#endif
 
 #include "gs-listener-dbus.h"
 #include "gs-marshal.h"
@@ -61,12 +64,12 @@ static DBusHandlerResult gs_listener_message_handler    (DBusConnection  *connec
 #define HAL_DEVICE_INTERFACE "org.freedesktop.Hal.Device"
 
 /* systemd logind */
-#define SYSTEMD_LOGIND_SERVICE   "org.freedesktop.login1"
-#define SYSTEMD_LOGIND_PATH      "/org/freedesktop/login1"
-#define SYSTEMD_LOGIND_INTERFACE "org.freedesktop.login1.Manager"
+#define LOGIND_SERVICE   "org.freedesktop.login1"
+#define LOGIND_PATH      "/org/freedesktop/login1"
+#define LOGIND_INTERFACE "org.freedesktop.login1.Manager"
 
-#define SYSTEMD_LOGIND_SESSION_INTERFACE "org.freedesktop.login1.Session"
-#define SYSTEMD_LOGIND_SESSION_PATH      "/org/freedesktop/login1/session"
+#define LOGIND_SESSION_INTERFACE "org.freedesktop.login1.Session"
+#define LOGIND_SESSION_PATH      "/org/freedesktop/login1/session"
 
 /* consolekit */
 #define CK_NAME              "org.freedesktop.ConsoleKit"
@@ -74,10 +77,6 @@ static DBusHandlerResult gs_listener_message_handler    (DBusConnection  *connec
 #define CK_MANAGER_INTERFACE "org.freedesktop.ConsoleKit.Manager"
 #define CK_SESSION_INTERFACE "org.freedesktop.ConsoleKit.Session"
 
-#define SESSION_NAME         "org.gnome.SessionManager"
-#define SESSION_PATH         "/org/gnome/SessionManager"
-#define SESSION_INTERFACE    "org.gnome.SessionManager"
-
 #define TYPE_MISMATCH_ERROR GS_LISTENER_INTERFACE ".TypeMismatch"
 
 struct GSListenerPrivate {
@@ -95,8 +94,8 @@ struct GSListenerPrivate {
     time_t          session_idle_start;
     char           *session_id;
 
-#ifdef WITH_SYSTEMD
-    gboolean have_systemd;
+#if defined(WITH_SYSTEMD) || defined(WITH_ELOGIND)
+    gboolean have_logind;
 #endif
 
     guint32         ck_throttle_cookie;
@@ -108,7 +107,7 @@ typedef struct {
     char     *reason;
     char     *connection;
     guint32   cookie;
-    guint32   foreign_cookie;
+    gint32    fd;
     GTimeVal  since;
 } GSListenerRefEntry;
 
@@ -165,7 +164,6 @@ gs_listener_ref_entry_free (GSListenerRefEntry *entry) {
     g_free (entry->application);
     g_free (entry->reason);
     g_free (entry);
-    entry = NULL;
 }
 
 static void
@@ -468,24 +466,6 @@ gs_listener_set_session_idle (GSListener *listener,
     return res;
 }
 
-gboolean
-gs_listener_get_activation_enabled (GSListener *listener) {
-    g_return_val_if_fail (GS_IS_LISTENER (listener), FALSE);
-
-    return listener->priv->activation_enabled;
-}
-
-gboolean
-gs_listener_is_inhibited (GSListener *listener) {
-    gboolean inhibited;
-
-    g_return_val_if_fail (GS_IS_LISTENER (listener), FALSE);
-
-    inhibited = listener_ref_entry_is_present (listener, REF_ENTRY_TYPE_INHIBIT);
-
-    return inhibited;
-}
-
 void
 gs_listener_set_activation_enabled (GSListener *listener,
                                     gboolean    enabled) {
@@ -604,34 +584,44 @@ listener_ref_entry_check (GSListener *listener,
 static void
 add_session_inhibit (GSListener         *listener,
                      GSListenerRefEntry *entry) {
-    DBusMessage     *message;
-    DBusMessage     *reply;
-    DBusMessageIter  iter;
-    DBusMessageIter  reply_iter;
+    DBusMessage     *message = NULL, *reply = NULL;
+    DBusMessageIter  iter, reply_iter;
     DBusError        error;
-    guint            xid;
-    guint            flags;
+    const gchar     *mode = "block";
+    /* it is a colon-separated list of lock types */
+    const gchar     *what = "idle";
 
     g_return_if_fail (listener != NULL);
 
     dbus_error_init (&error);
 
-    message = dbus_message_new_method_call (SESSION_NAME,
-                                            SESSION_PATH,
-                                            SESSION_INTERFACE,
+#if defined(WITH_SYSTEMD) || defined(WITH_ELOGIND)
+    message = dbus_message_new_method_call (LOGIND_SERVICE,
+                                            LOGIND_PATH,
+                                            LOGIND_INTERFACE,
                                             "Inhibit");
+#elif defined(WITH_CONSOLE_KIT)
+    message = dbus_message_new_method_call (CK_NAME,
+                                            CK_MANAGER_PATH,
+                                            CK_MANAGER_INTERFACE,
+                                            "Inhibit");
+#endif
     if (message == NULL) {
         gs_debug ("Couldn't allocate the dbus message");
         return;
     }
 
     dbus_message_iter_init_append (message, &iter);
-    xid = 0;
-    flags = 8;
-    dbus_message_iter_append_basic (&iter, DBUS_TYPE_STRING, &entry->application);
-    dbus_message_iter_append_basic (&iter, DBUS_TYPE_UINT32, &xid);
-    dbus_message_iter_append_basic (&iter, DBUS_TYPE_STRING, &entry->reason);
-    dbus_message_iter_append_basic (&iter, DBUS_TYPE_UINT32, &flags);
+    /* what parameter */
+    dbus_message_iter_append_basic (&iter, DBUS_TYPE_STRING, &what);
+    /* who parameter */
+    dbus_message_iter_append_basic (&iter, DBUS_TYPE_STRING,
+                                    &entry->application);
+    /* why parameter */
+    dbus_message_iter_append_basic (&iter, DBUS_TYPE_STRING,
+                                    &entry->reason);
+    /* mode parameter */
+    dbus_message_iter_append_basic (&iter, DBUS_TYPE_STRING, &mode);
 
     /* FIXME: use async? */
     reply = dbus_connection_send_with_reply_and_block (listener->priv->connection,
@@ -647,54 +637,23 @@ add_session_inhibit (GSListener         *listener,
     }
 
     dbus_message_iter_init (reply, &reply_iter);
-    dbus_message_iter_get_basic (&reply_iter, &entry->foreign_cookie);
+    if (DBUS_TYPE_UNIX_FD == dbus_message_iter_get_arg_type(&reply_iter))
+        dbus_message_iter_get_basic (&reply_iter, &entry->fd);
 
     dbus_message_unref (reply);
 }
 
 static void
-remove_session_inhibit (GSListener         *listener,
-                        GSListenerRefEntry *entry) {
-    DBusMessage     *message;
-    DBusMessage     *reply;
-    DBusMessageIter  iter;
-    DBusError        error;
-
-    g_return_if_fail (listener != NULL);
-
-    if (entry->foreign_cookie == 0) {
+remove_session_inhibit (GSListenerRefEntry *entry) {
+    if (entry->fd < 0) {
         gs_debug ("Can't remove inhibitor from session: Session cookie not set");
         return;
     }
 
-    dbus_error_init (&error);
-
-    message = dbus_message_new_method_call (SESSION_NAME,
-                                            SESSION_PATH,
-                                            SESSION_INTERFACE,
-                                            "Uninhibit");
-    if (message == NULL) {
-        gs_debug ("Couldn't allocate the dbus message");
+    if (close(entry->fd) < 0) {
+        gs_debug ("Can't close file descriptor");
         return;
     }
-
-    dbus_message_iter_init_append (message, &iter);
-    dbus_message_iter_append_basic (&iter, DBUS_TYPE_UINT32, &entry->foreign_cookie);
-
-    /* FIXME: use async? */
-    reply = dbus_connection_send_with_reply_and_block (listener->priv->connection,
-            message,
-            -1,
-            &error);
-    dbus_message_unref (message);
-
-    if (dbus_error_is_set (&error)) {
-        gs_debug ("%s raised:\n %s\n\n", error.name, error.message);
-        dbus_error_free (&error);
-        return;
-    }
-
-    dbus_message_unref (reply);
 }
 
 static void
@@ -725,11 +684,9 @@ listener_remove_ref_entry (GSListener *listener,
                            int         entry_type,
                            guint32     cookie) {
     GHashTable         *hash;
-    gboolean            removed;
+    gboolean            removed = FALSE;
     GSListenerRefEntry *entry;
 
-    removed = FALSE;
-
     hash = get_hash_for_entry_type (listener, entry_type);
 
     entry = g_hash_table_lookup (hash, &cookie);
@@ -745,7 +702,7 @@ listener_remove_ref_entry (GSListener *listener,
 
     if (entry_type == REF_ENTRY_TYPE_INHIBIT) {
         /* remove inhibit from xfce session */
-        remove_session_inhibit (listener, entry);
+        remove_session_inhibit (entry);
     }
 
     removed = g_hash_table_remove (hash, &cookie);
@@ -977,7 +934,7 @@ listener_ref_entry_remove_for_connection (GSListener  *listener,
 
             if (entry->entry_type == REF_ENTRY_TYPE_INHIBIT) {
                 /* remove inhibit from xfce session */
-                remove_session_inhibit (listener, entry);
+                remove_session_inhibit (entry);
             }
 
             g_hash_table_iter_remove (&iter);
@@ -1393,7 +1350,7 @@ _listener_message_path_is_our_session (GSListener  *listener,
     return FALSE;
 }
 
-#ifdef WITH_SYSTEMD
+#if defined(WITH_SYSTEMD) || defined(WITH_ELOGIND)
 static gboolean
 properties_changed_match (DBusMessage *message,
                           const char  *property) {
@@ -1472,7 +1429,7 @@ listener_dbus_handle_system_message (DBusConnection *connection,
     g_return_val_if_fail (connection != NULL, DBUS_HANDLER_RESULT_NOT_YET_HANDLED);
     g_return_val_if_fail (message != NULL, DBUS_HANDLER_RESULT_NOT_YET_HANDLED);
 
-#if 1
+#if 0
     gs_debug ("obj_path=%s interface=%s method=%s destination=%s",
               dbus_message_get_path (message),
               dbus_message_get_interface (message),
@@ -1480,26 +1437,28 @@ listener_dbus_handle_system_message (DBusConnection *connection,
               dbus_message_get_destination (message));
 #endif
 
-#ifdef WITH_SYSTEMD
-    if (listener->priv->have_systemd) {
-        if (dbus_message_is_signal (message, SYSTEMD_LOGIND_SESSION_INTERFACE, "Unlock")) {
+#if defined(WITH_SYSTEMD) || defined(WITH_ELOGIND)
+    if (listener->priv->have_logind) {
+        if (dbus_message_is_signal (message, LOGIND_SESSION_INTERFACE, "Unlock")) {
             if (_listener_message_path_is_our_session (listener, message)) {
                 gs_debug ("Systemd requested session unlock");
                 gs_listener_set_active (listener, FALSE);
             }
 
             return DBUS_HANDLER_RESULT_HANDLED;
-        } else if (dbus_message_is_signal (message, SYSTEMD_LOGIND_SESSION_INTERFACE, "Lock")) {
+        } else if (dbus_message_is_signal (message, LOGIND_SESSION_INTERFACE, "Lock")) {
             if (_listener_message_path_is_our_session (listener, message)) {
                 gs_debug ("Systemd requested session lock");
                 g_signal_emit (listener, signals[LOCK], 0);
             }
 
             return DBUS_HANDLER_RESULT_HANDLED;
-        } else if (dbus_message_is_signal (message, SYSTEMD_LOGIND_INTERFACE, "PrepareForSleep")) {
+        } else if (dbus_message_is_signal (message, LOGIND_INTERFACE, "PrepareForSleep")) {
             gboolean  active = 0;
             DBusError error;
 
+            gs_debug ("Handling Logind PrepareForSleep");
+
             dbus_error_init (&error);
             dbus_message_get_args (message, &error, DBUS_TYPE_BOOLEAN, &active, DBUS_TYPE_INVALID);
             if (active) {
@@ -1515,6 +1474,10 @@ listener_dbus_handle_system_message (DBusConnection *connection,
                 g_signal_emit (listener, signals[SHOW_MESSAGE], 0, NULL, NULL, NULL);
             }
 
+            if (dbus_error_is_set (&error)) {
+                dbus_error_free (&error);
+            }
+
             return DBUS_HANDLER_RESULT_HANDLED;
         } else if (dbus_message_is_signal (message, DBUS_INTERFACE_PROPERTIES, "PropertiesChanged")) {
             if (_listener_message_path_is_our_session (listener, message)) {
@@ -2059,29 +2022,29 @@ gs_listener_acquire (GSListener  *listener,
                                     listener_dbus_system_filter_function,
                                     listener,
                                     NULL);
-#ifdef WITH_SYSTEMD
-        if (listener->priv->have_systemd) {
+#if defined(WITH_SYSTEMD) || defined(WITH_ELOGIND)
+        if (listener->priv->have_logind) {
             dbus_bus_add_match (listener->priv->system_connection,
                                 "type='signal'"
-                                ",sender='"SYSTEMD_LOGIND_SERVICE"'"
-                                ",interface='"SYSTEMD_LOGIND_SESSION_INTERFACE"'"
+                                ",sender='"LOGIND_SERVICE"'"
+                                ",interface='"LOGIND_SESSION_INTERFACE"'"
                                 ",member='Unlock'",
                                 NULL);
             dbus_bus_add_match (listener->priv->system_connection,
                                 "type='signal'"
-                                ",sender='"SYSTEMD_LOGIND_SERVICE"'"
-                                ",interface='"SYSTEMD_LOGIND_SESSION_INTERFACE"'"
+                                ",sender='"LOGIND_SERVICE"'"
+                                ",interface='"LOGIND_SESSION_INTERFACE"'"
                                 ",member='Lock'",
                                 NULL);
             dbus_bus_add_match (listener->priv->system_connection,
                                 "type='signal'"
-                                ",sender='"SYSTEMD_LOGIND_SERVICE"'"
-                                ",interface='"SYSTEMD_LOGIND_INTERFACE"'"
+                                ",sender='"LOGIND_SERVICE"'"
+                                ",interface='"LOGIND_INTERFACE"'"
                                 ",member='PrepareForSleep'",
                                 NULL);
             dbus_bus_add_match (listener->priv->system_connection,
                                 "type='signal'"
-                                ",sender='"SYSTEMD_LOGIND_SERVICE"'"
+                                ",sender='"LOGIND_SERVICE"'"
                                 ",interface='"DBUS_INTERFACE_PROPERTIES"'"
                                 ",member='PropertiesChanged'",
                                 NULL);
@@ -2134,14 +2097,14 @@ query_session_id (GSListener *listener) {
 
     dbus_error_init (&error);
 
-#ifdef WITH_SYSTEMD
-    if (listener->priv->have_systemd) {
+#if defined(WITH_SYSTEMD) || defined(WITH_ELOGIND)
+    if (listener->priv->have_logind) {
         dbus_uint32_t pid = getpid();
 
-        message = dbus_message_new_method_call (SYSTEMD_LOGIND_SERVICE,
-                                                SYSTEMD_LOGIND_PATH,
-                            SYSTEMD_LOGIND_INTERFACE,
-                            "GetSessionByPID");
+        message = dbus_message_new_method_call (LOGIND_SERVICE,
+                                                LOGIND_PATH,
+                                                LOGIND_INTERFACE,
+                                                "GetSessionByPID");
         if (message == NULL) {
             gs_debug ("Couldn't allocate the dbus message");
             return NULL;
@@ -2216,9 +2179,9 @@ static void
 gs_listener_init (GSListener *listener) {
     listener->priv = gs_listener_get_instance_private (listener);
 
-#ifdef WITH_SYSTEMD
+#if defined(WITH_SYSTEMD) || defined(WITH_ELOGIND)
     /* check if logind is running */
-    listener->priv->have_systemd = (access("/run/systemd/seats/", F_OK) >= 0);
+    listener->priv->have_logind = (access("/run/systemd/seats/", F_OK) >= 0);
 #endif
 
     gs_listener_dbus_init (listener);
