@@ -33,7 +33,6 @@
 
 #include "gs-debug.h"
 #include "gs-grab.h"
-#include "gs-fade.h"
 #include "gs-job.h"
 #include "gs-manager.h"
 #include "gs-prefs.h"        /* for GSSaverMode */
@@ -76,9 +75,7 @@ struct GSManagerPrivate {
     guint           lock_active : 1;
     guint           saver_active : 1;
 
-    guint           fading : 1;
     guint           dialog_up : 1;
-    gint            last_monitor_count;
 
     time_t          activate_time;
 
@@ -88,8 +85,6 @@ struct GSManagerPrivate {
     GSList         *themes;
     GSSaverMode     saver_mode;
     GSGrab         *grab;
-    GSFade         *fade;
-    guint           unfade_idle_id;
     guint           deepsleep_idle_id;
     gboolean        deepsleep;
 };
@@ -120,8 +115,6 @@ enum {
     PROP_THROTTLED,
 };
 
-#define FADE_TIMEOUT 1000
-
 static guint         signals[LAST_SIGNAL] = { 0, };
 
 G_DEFINE_TYPE_WITH_PRIVATE (GSManager, gs_manager, G_TYPE_OBJECT)
@@ -130,6 +123,19 @@ static void         remove_deepsleep_idle   (GSManager *manager);
 static gboolean     deepsleep_idle          (GSManager *manager);
 static void         add_deepsleep_idle      (GSManager *manager);
 
+static gint
+manager_get_monitor_index (GdkMonitor *this_monitor) {
+    GdkDisplay *display = gdk_monitor_get_display (this_monitor);
+    gint        idx;
+
+    for (idx = 0; idx < gdk_display_get_n_monitors (display); idx++) {
+        GdkMonitor *monitor = gdk_display_get_monitor (display, idx);
+        if (monitor == this_monitor)
+            return idx;
+    }
+    return 0;
+}
+
 static void
 manager_add_job_for_window (GSManager *manager,
                             GSWindow  *window,
@@ -447,20 +453,6 @@ gs_manager_set_saver_active (GSManager *manager,
     }
 }
 
-void
-gs_manager_get_saver_enabled (GSManager *manager,
-                              gboolean  *saver_enabled) {
-    if (saver_enabled != NULL) {
-        *saver_enabled = FALSE;
-    }
-
-    g_return_if_fail (GS_IS_MANAGER (manager));
-
-    if (saver_enabled != NULL) {
-        *saver_enabled = manager->priv->saver_enabled;
-    }
-}
-
 void
 gs_manager_set_saver_enabled (GSManager *manager,
                               gboolean   saver_enabled) {
@@ -471,20 +463,6 @@ gs_manager_set_saver_enabled (GSManager *manager,
     }
 }
 
-void
-gs_manager_get_lock_enabled (GSManager *manager,
-                             gboolean  *lock_enabled) {
-    if (lock_enabled != NULL) {
-        *lock_enabled = FALSE;
-    }
-
-    g_return_if_fail (GS_IS_MANAGER (manager));
-
-    if (lock_enabled != NULL) {
-        *lock_enabled = manager->priv->lock_enabled;
-    }
-}
-
 void
 gs_manager_set_lock_enabled (GSManager *manager,
                              gboolean   lock_enabled) {
@@ -686,14 +664,14 @@ gs_manager_set_status_message_enabled (GSManager  *manager,
 
 void
 gs_manager_set_status_message (GSManager  *manager,
-                               const char *status_message) {
+                               const char *message) {
     GSList *l;
 
     g_return_if_fail (GS_IS_MANAGER (manager));
 
     g_free (manager->priv->status_message);
 
-    manager->priv->status_message = g_strdup (status_message);
+    manager->priv->status_message = g_strdup (message);
 
     for (l = manager->priv->windows; l; l = l->next) {
         gs_window_set_status_message (l->data, manager->priv->status_message);
@@ -1022,7 +1000,6 @@ static void
 gs_manager_init (GSManager *manager) {
     manager->priv = gs_manager_get_instance_private (manager);
 
-    manager->priv->fade = gs_fade_new ();
     manager->priv->grab = gs_grab_new ();
     manager->priv->theme_manager = gs_theme_manager_new ();
 
@@ -1039,15 +1016,6 @@ remove_timers (GSManager *manager) {
     remove_cycle_timer (manager);
 }
 
-static void
-remove_unfade_idle (GSManager *manager) {
-    if (manager->priv->unfade_idle_id > 0) {
-        g_source_remove (manager->priv->unfade_idle_id);
-        manager->priv->unfade_idle_id = 0;
-    }
-}
-
-
 static gboolean
 window_deactivated_idle (GSManager *manager) {
     g_return_val_if_fail (manager != NULL, FALSE);
@@ -1075,8 +1043,7 @@ find_window_at_pointer (GSManager *manager) {
     GdkDevice  *device;
     GdkMonitor *monitor;
     int         x, y;
-    GSWindow   *window;
-    GSList     *l;
+    GSList     *window;
 
     display = gdk_display_get_default ();
 
@@ -1085,15 +1052,7 @@ find_window_at_pointer (GSManager *manager) {
     monitor = gdk_display_get_monitor_at_point (display, x, y);
 
     /* Find the gs-window that is on that monitor */
-    window = NULL;
-    for (l = manager->priv->windows; l; l = l->next) {
-        GSWindow *win = GS_WINDOW (l->data);
-        if (gs_window_get_display (win) == display &&
-                gs_window_get_monitor (win) == monitor) {
-            window = win;
-        }
-    }
-
+    window = g_slist_nth (manager->priv->windows, manager_get_monitor_index (monitor));
     if (window == NULL) {
         gs_debug ("WARNING: Could not find the GSWindow for display %s",
                   gdk_display_get_name (display));
@@ -1108,7 +1067,7 @@ find_window_at_pointer (GSManager *manager) {
                   gdk_display_get_name (display));
     }
 
-    return window;
+    return GS_WINDOW (window->data);
 }
 
 void
@@ -1182,19 +1141,6 @@ window_grab_broken_cb (GSWindow           *window,
     }
 }
 
-static gboolean
-unfade_idle (GSManager *manager) {
-    gs_fade_reset (manager->priv->fade);
-    manager->priv->unfade_idle_id = 0;
-    return FALSE;
-}
-
-static void
-add_unfade_idle (GSManager *manager) {
-    remove_unfade_idle (manager);
-    manager->priv->unfade_idle_id = g_timeout_add (500, (GSourceFunc)unfade_idle, manager);
-}
-
 static void
 remove_deepsleep_idle (GSManager *manager) {
     if (manager->priv->deepsleep_idle_id > 0) {
@@ -1283,8 +1229,6 @@ manager_show_window (GSManager *manager,
         add_cycle_timer (manager, manager->priv->cycle_timeout);
     }
 
-    add_unfade_idle (manager);
-
     /* FIXME: only emit signal once */
     g_signal_emit (manager, signals[ACTIVATED], 0);
 }
@@ -1465,10 +1409,15 @@ gs_manager_create_window_for_monitor (GSManager  *manager,
     GSWindow    *window;
     GdkRectangle rect;
 
+    if (g_slist_nth (manager->priv->windows, manager_get_monitor_index(monitor))) {
+        gs_debug ("Found already created window for Monitor %d", manager_get_monitor_index(monitor));
+        return;
+    }
+
     gdk_monitor_get_geometry (monitor, &rect);
 
-    gs_debug ("Creating a window [%d,%d] (%dx%d)",
-              rect.x, rect.y, rect.width, rect.height);
+    gs_debug ("Creating a Window [%d,%d] (%dx%d) for monitor %d",
+              rect.x, rect.y, rect.width, rect.height, manager_get_monitor_index (monitor));
 
     window = gs_window_new (monitor,
                             manager->priv->lock_enabled,
@@ -1486,40 +1435,13 @@ gs_manager_create_window_for_monitor (GSManager  *manager,
 
     connect_window_signals (manager, window);
 
-    manager->priv->windows = g_slist_append (manager->priv->windows, window);
+    manager->priv->windows = g_slist_insert (manager->priv->windows, window, manager_get_monitor_index(monitor));
 
-    if (manager->priv->active && !manager->priv->fading) {
+    if (manager->priv->active) {
         gtk_widget_show (GTK_WIDGET (window));
     }
 }
 
-static gboolean
-gs_manager_is_real_monitor (GdkMonitor *monitor) {
-    // avoiding some weird gdk bug
-    // federico> avb: or if you don't care about a little unexplained messiness,
-    //                just discard monitors where both fields are null? :)
-    if (gdk_monitor_get_manufacturer(monitor) == NULL && gdk_monitor_get_model(monitor) == NULL)
-        return FALSE;
-    return TRUE;
-}
-
-static int
-gs_manager_get_n_monitors (GdkDisplay *display) {
-    // Since gdk_display_get_n_monitors return wrong monitor count
-    // this is a workaround for the problem
-    GdkMonitor *monitor;
-    int        n_monitors;
-    int        i, count = 0;
-
-    n_monitors = gdk_display_get_n_monitors (display);
-    for (i = 0; i < n_monitors; i++) {
-        monitor = gdk_display_get_monitor(display, i);
-        if (gs_manager_is_real_monitor (monitor))
-            count++;
-    }
-    return count;
-}
-
 static void
 on_display_monitor_added (GdkDisplay *display,
                           GdkMonitor *monitor,
@@ -1527,101 +1449,33 @@ on_display_monitor_added (GdkDisplay *display,
     GSList     *l;
     int         n_monitors;
 
-    g_return_if_fail (gs_manager_is_real_monitor(monitor));
+    n_monitors = gdk_display_get_n_monitors (display);
 
-    n_monitors = gs_manager_get_n_monitors (display);
+    gs_debug ("Monitor %s added on display %s, now there are %d",
+              gdk_monitor_get_model(monitor), gdk_display_get_name (display), n_monitors);
 
-    gs_debug ("Monitor added on display %s, now there are %d",
-              gdk_display_get_name (display), n_monitors);
-
-    if (manager->priv->last_monitor_count == 0) {
-        /* Tidy up from lid-close or other headless event once we have a new monitor.
-         * See https://gitlab.gnome.org/GNOME/gtk/issues/1466
-         */
-        l = manager->priv->windows;
-        while (l != NULL)
-        {
-            GSList *next = l->next;
-
-            manager_maybe_stop_job_for_window(manager,
-                                                GS_WINDOW(l->data));
-            g_hash_table_remove(manager->priv->jobs, l->data);
-            gs_window_disconnect_monitor(GS_WINDOW(l->data));
-            gs_window_destroy(GS_WINDOW(l->data));
-            manager->priv->windows = g_slist_delete_link(manager->priv->windows, l);
-            l = next;
-        }
-    }
-
-    manager->priv->last_monitor_count = n_monitors;
-
-    /* add a new window */
-    gs_manager_create_window_for_monitor (manager, monitor);
-
-    /* Tear down the unlock dialog in case we want to move it
-     * to the new monitor
-     */
-    l = manager->priv->windows;
-    while (l != NULL) {
-        gs_window_cancel_unlock_request (GS_WINDOW (l->data));
-        l = l->next;
+    l = g_slist_nth (manager->priv->windows, manager_get_monitor_index (monitor));
+    if (l) {
+        gs_debug ("Found window for this Monitor");
+        gs_window_set_monitor (GS_WINDOW (l->data), monitor);
+    } else {
+        gs_debug("Creating new window for Monitor %s", gdk_monitor_get_model (monitor));
+        gs_manager_create_window_for_monitor(manager, monitor);
+        l = g_slist_nth (manager->priv->windows, manager_get_monitor_index (monitor));
     }
+    gs_window_request_unlock (l->data);
 }
 
 static void
 on_display_monitor_removed (GdkDisplay *display,
                             GdkMonitor *monitor,
                             GSManager  *manager) {
-    GSList     *l;
     int         n_monitors;
-    GdkMonitor *last_monitor = NULL;
 
-    g_return_if_fail (gs_manager_is_real_monitor(monitor));
+    n_monitors = gdk_display_get_n_monitors (display);
 
-    n_monitors = manager->priv->last_monitor_count = gs_manager_get_n_monitors (display);
-
-    gs_debug ("Monitor removed on display %s, now there are %d",
-              gdk_display_get_name (display), n_monitors);
-
-    /* Tidy up from lid-close or other headless event once we have a new monitor.
-     * See https://gitlab.gnome.org/GNOME/gtk/issues/1466
-     */
-    if (n_monitors == 0)
-        return;
-
-    gdk_x11_grab_server ();
-
-    /* remove the now extra window */
-    l = manager->priv->windows;
-    while (l != NULL) {
-        GdkDisplay *this_display;
-        GdkMonitor *this_monitor;
-        GSList     *next = l->next;
-
-        this_display = gs_window_get_display (GS_WINDOW (l->data));
-        this_monitor = gs_window_get_monitor (GS_WINDOW (l->data));
-        if (this_display == display && this_monitor == monitor) {
-            manager_maybe_stop_job_for_window (manager,
-                                               GS_WINDOW (l->data));
-            g_hash_table_remove (manager->priv->jobs, l->data);
-            gs_window_destroy (GS_WINDOW (l->data));
-            manager->priv->windows = g_slist_delete_link (manager->priv->windows, l);
-        } else {
-            last_monitor = this_monitor;
-            gs_window_cancel_unlock_request (GS_WINDOW (l->data));
-        }
-        l = next;
-    }
-
-    gdk_display_flush (display);
-    gdk_x11_ungrab_server ();
-
-    /* add a new window */
-    if (last_monitor)
-        gs_manager_create_window_for_monitor(manager, last_monitor);
-
-    /* and put unlock dialog up whereever it's supposed to be */
-    gs_manager_request_unlock(manager);
+    gs_debug ("Monitor %p removed on display %s, now there are %d",
+              monitor, gdk_display_get_name (display), n_monitors);
 }
 
 static void
@@ -1672,7 +1526,6 @@ gs_manager_finalize (GObject *object) {
     g_free (manager->priv->keyboard_command);
     g_free (manager->priv->status_message);
 
-    remove_unfade_idle (manager);
     remove_deepsleep_idle (manager);
     remove_timers(manager);
 
@@ -1687,7 +1540,6 @@ gs_manager_finalize (GObject *object) {
     manager->priv->lock_enabled = FALSE;
     manager->priv->lock_with_saver_enabled = FALSE;
 
-    g_object_unref (manager->priv->fade);
     g_object_unref (manager->priv->grab);
     g_object_unref (manager->priv->theme_manager);
 
@@ -1749,7 +1601,6 @@ gs_manager_new (void) {
     manager = g_object_new (GS_TYPE_MANAGER, NULL);
 
     mgr = GS_MANAGER (manager);
-    mgr->priv->last_monitor_count = -1;
 
     return mgr;
 }
@@ -1773,17 +1624,8 @@ remove_job (GSJob *job) {
     g_object_unref (job);
 }
 
-static void
-fade_done_cb (GSFade    *fade,
-              GSManager *manager) {
-    gs_debug ("Fade completed, showing windows");
-    show_windows (manager->priv->windows);
-    manager->priv->fading = FALSE;
-}
-
 static gboolean
 gs_manager_activate (GSManager *manager) {
-    gboolean    do_fade;
     gboolean    res;
 
     g_return_val_if_fail (manager != NULL, FALSE);
@@ -1810,22 +1652,7 @@ gs_manager_activate (GSManager *manager) {
 
     manager->priv->active = TRUE;
 
-    /* fade to black and show windows */
-    do_fade = FALSE;
-    if (do_fade) {
-        manager->priv->fading = TRUE;
-        gs_debug ("Fading out");
-        gs_fade_async (manager->priv->fade,
-                       FADE_TIMEOUT,
-                       (GSFadeDoneFunc)fade_done_cb,
-                       manager);
-
-        while (manager->priv->fading) {
-            gtk_main_iteration ();
-        }
-    } else {
-        show_windows (manager->priv->windows);
-    }
+    show_windows (manager->priv->windows);
 
     return TRUE;
 }
@@ -1840,8 +1667,6 @@ gs_manager_deactivate (GSManager *manager) {
         return FALSE;
     }
 
-    remove_unfade_idle (manager);
-    gs_fade_reset (manager->priv->fade);
     remove_timers (manager);
 
     gs_grab_release (manager->priv->grab, TRUE);
@@ -1854,7 +1679,6 @@ gs_manager_deactivate (GSManager *manager) {
     manager->priv->active = FALSE;
     manager->priv->activate_time = 0;
     manager->priv->dialog_up = FALSE;
-    manager->priv->fading = FALSE;
 
     gs_manager_set_lock_active (manager, FALSE);
 
@@ -1900,11 +1724,6 @@ gs_manager_request_unlock (GSManager *manager) {
         return FALSE;
     }
 
-    if (manager->priv->fading) {
-        gs_debug ("Request unlock so finishing fade");
-        gs_fade_finish (manager->priv->fade);
-    }
-
     if (manager->priv->windows == NULL) {
         gs_debug ("We don't have any windows!");
         return FALSE;
@@ -1916,11 +1735,3 @@ gs_manager_request_unlock (GSManager *manager) {
 
     return TRUE;
 }
-
-void
-gs_manager_cancel_unlock_request (GSManager *manager) {
-    GSList *l;
-    for (l = manager->priv->windows; l; l = l->next) {
-        gs_window_cancel_unlock_request (l->data);
-    }
-}
