@@ -65,8 +65,6 @@ void        gs_window_set_monitor             (GSWindow        *window,
                                                GdkMonitor      *monitor);
 GdkMonitor *gs_window_get_monitor             (GSWindow        *window);
 
-void        gs_window_set_background_surface  (GSWindow        *window,
-                                               cairo_surface_t *surface);
 void        gs_window_set_lock_enabled        (GSWindow        *window,
                                                gboolean         lock_enabled);
 void        gs_window_set_lock_with_saver_enabled (GSWindow    *window,
@@ -107,7 +105,6 @@ void        gs_window_destroy                 (GSWindow        *window);
 GdkWindow * gs_window_get_gdk_window          (GSWindow        *window);
 GtkWidget * gs_window_get_drawing_area        (GSWindow        *window);
 void        gs_window_clear                   (GSWindow        *window);
-void        gs_window_disconnect_monitor      (GSWindow        *window);
 
 G_END_DECLS
 
