@@ -296,6 +296,9 @@ get_string_from_iter (DBusMessageIter *iter,
     return buffer;
 
 oom:
+    if (buffer != NULL) {
+        free (buffer);
+    }
     g_debug ("%s %d : error allocating memory\n", __FILE__, __LINE__);
     return NULL;
 }
@@ -381,15 +384,15 @@ do_command (DBusConnection *connection) {
     }
 
     if (do_lock) {
-        reply = screensaver_send_message_void (connection, "Lock", FALSE);
+        screensaver_send_message_void (connection, "Lock", FALSE);
     }
 
     if (do_cycle) {
-        reply = screensaver_send_message_void (connection, "Cycle", FALSE);
+        screensaver_send_message_void (connection, "Cycle", FALSE);
     }
 
     if (do_poke) {
-        reply = screensaver_send_message_void (connection, "SimulateUserActivity", FALSE);
+        screensaver_send_message_void (connection, "SimulateUserActivity", FALSE);
     }
 
     if (do_activate) {
